References
==========

Additional Resources
--------------------

To seek support or report issues, e-mail:

 * ``parmoo@lbl.gov``

For permissions, see the following:

 * LICENSE_
 * CONTRIBUTING_

Our full user guide is hosted here:

 * ReadTheDocs_

Reference Format
----------------

Please use one or more of the following to cite ParMOO.

Our JOSS paper:

.. code-block:: bibtex

    @article{parmoo,
        author={Chang, Tyler H. and Wild, Stefan M.},
        title={{ParMOO}: A {P}ython library for parallel multiobjective simulation optimization},
        year={2023},
        journal = {Journal of Open Source Software},
        volume = {8},
        number = {82},
        pages = {4468},
        doi = {10.21105/joss.04468}
    }

Our online documentation:

.. code-block:: bibtex

    @techreport{parmoo-docs,
        title       = {{ParMOO}: {P}ython library for parallel multiobjective simulation optimization},
        author      = {Chang, Tyler H. and Wild, Stefan M. and Dickinson, Hyrum},
        institution = {Argonne National Laboratory},
        number      = {Version 0.4.1},
        year        = {2024},
        url         = {https://parmoo.readthedocs.io/en/latest}
    }

Our design principles paper:

.. code-block:: bibtex

    @techreport{ParMOODesign24,
        title = {Designing a Framework for Solving Multiobjective Simulation Optimization Problems},
        author = {Tyler H. Chang and Stefan M. Wild},
        institution = {arXiv},
        number = {2304.06881},
        year = {2024},
        url = {https://arxiv.org/abs/2304.06881},
    }

.. _CONTRIBUTING: https://github.com/parmoo/parmoo/blob/main/CONTRIBUTING.rst
.. _LICENSE: https://github.com/parmoo/parmoo/blob/main/LICENSE
.. _ReadTheDocs: https://parmoo.readthedocs.org
